Compositions
============

Collections of `Core` `Components` and/or other Compositions that implement a model of the mechanism(s) underlying a
particular brain function and/or psychological process.

.. toctree::
   :maxdepth: 2

   AGT
   EVC
